Package 'data.camp'

Title: Stores some useful data sets for CAMP-BNU
Description: This is a quick way to share data sets for CAMP-BNU.
Authors: Liang Zhang [aut, cre] (ORCID: <https://orcid.org/0000-0001-9041-1150>)
Maintainer: Liang Zhang <[email protected]>
License: file LICENSE
Version: 0.0.2
Built: 2026-06-08 08:15:46 UTC
Source: https://github.com/CAMP-BNU/data.camp

Help Index


The mapping between behavior and fMRI user

Description

For some real-world reasons, the user id in behavior data and fMRI data are not the same. This dataset provides the mapping between them.

Usage

users_id_mapping

Format

A named character vector with fMRI user id as names and behavior user id as values.